\name{msb}
\alias{msb}
\title{Plot genomic map for SNP, with major transcripts.}
\usage{
  msb(M, start = start, end = end, extendL = 1,
    extendR = 1, cex = 0.6, showLab.chr = TRUE,
    axisLabPos = "alternating", littleTicks = FALSE,
    geneTrName = "Gene", showLab.geneTr = TRUE,
    stackHt.geneTr = 0.5, SNPbpTrName = "SNP",
    SNPbpLab = 1:nr, showLab.SNPbp = FALSE, SNPbpWd = 1,
    SNPbpFill = "black", stackHt.SNPbpTr = 0.5,
    SNPidTrName = "ID", showLab.SNPid = TRUE, SNPidWd = 1,
    SNPidPos = "below", stackHt.SNPidTr = 0.2,
    stacking = "dense", genome = "hg19",
    reverseStrand = FALSE, background.panel = "white",
    background.title = "grey", ...)
}
\arguments{
  \item{axisLabPos}{Character vector, one in "alternating",
  "revAlternating", "above" or "below". The vertical
  positioning of the axis labels. Default to
  "alternating".}

  \item{cex}{Numeric scalar. The overall font expansion
  factor for the axis annotation text. Default to 0.6.}

  \item{background.panel}{A character, background color of
  track panel. Default to "white".}

  \item{background.title}{A character, background color of
  track name. Default to "grey".}

  \item{end}{An integer scalar with the genomic end
  coordinates for the highlighting range.}

  \item{extendL}{Numeric scalar, extending the plotting
  range to the left by times of width relative the 1/10 of
  length of the genetic region. Default to 1.}

  \item{extendR}{Numeric scalar, extending the plotting
  range to the right by times of width relative the 1/10 of
  length of the genetic region. Default to 1.}

  \item{geneTrName}{Character scalar of the transcript
  track name used in the title panel when plotting. Default
  to "Transcripts".}

  \item{genome}{The genome on which the track ranges are
  defined. Usually this is a valid UCSC genome identifier.
  Default to "hg19".}

  \item{littleTicks}{littleTicks=FALSE: Logical scalar. Add
  more fine-grained tick marks. Default to FALSE.}

  \item{M}{A three-column matrix or data.fram. The first
  column is Chromosome, e.g. 1, 2, 3, ..., X, Y, the second
  column is SNP ID, and the third column is SNP genomic
  location.}

  \item{reverseStrand}{By default all tracks will be
  plotted in a 5' -> 3' direction. It sometimes can be
  useful to actually show the data relative to the opposite
  strand. To this end one can use the reverseStrand display
  parameter, which does just what its name suggests.
  Default to FALSE.}

  \item{showLab.chr}{Logical scalar. Control whether to
  plot the chromosome ideogram track item identifiers.
  Default to TRUE.}

  \item{showLab.geneTr}{Logical scalar. Control whether to
  plot the transcripts track item identifiers. Default to
  TRUE.}

  \item{showLab.SNPbp}{Logical scalar. Control whether to
  plot the SNP location track item identifiers. Default to
  FALSE.}

  \item{showLab.SNPid}{Logical scalar. Control whether to
  plot the SNP ID track item identifiers. Default to TRUE.}

  \item{SNPbpFill}{Character or integer scalar. The fill
  color for SNP location items.  Default to "black".}

  \item{SNPbpLab}{item labels for SNP location. Default to
  series from 1 to number of rows.}

  \item{SNPbpTrName}{Character scalar of the SNP location
  track name used in the title panel when plotting. Default
  to "SNP".}

  \item{SNPbpWd}{Integer vectors, times of width relative
  the 1/140 of length of the genetic region for the SNP
  location track items. Default to 1.}

  \item{SNPidPos}{Character vector, one in "alternating",
  "above" or "below". The vertical positioning of the SNP
  ID labels. Default to "alternating".}

  \item{SNPidTrName}{Character scalar of the SNP ID track
  name used in the title panel when plotting. Default to
  "ID".}

  \item{SNPidWd}{Integer vectors, times of width relative
  the 1/20 of length of the genetic region for the SNP ID
  track items. Default to 1.}

  \item{stackHt.geneTr}{Numeric between 0 and 1. Controls
  the vertical size and spacing between stacked elements.
  The number defines the proportion of the total available
  space for the stack that is used to draw the transcripts
  items. Default to 0.5.}

  \item{stackHt.SNPbpTr}{Numeric between 0 and 1. Controls
  the vertical size and spacing between stacked elements.
  The number defines the proportion of the total available
  space for the stack that is used to draw the SNP location
  items. Default to 0.5.}

  \item{stackHt.SNPidTr}{Numeric between 0 and 1. Controls
  the vertical size and spacing between stacked elements.
  The number defines the proportion of the total available
  space for the stack that is used to draw the SNP ID
  items. Default to 0.2.}

  \item{stacking}{Object of class "character", the stacking
  type of overlapping items on the final plot. One in
  c(hide, dense, squish, pack,full). Currently, only hide
  (do not show the track items at all), squish (make best
  use of the available space) and dense (no stacking at
  all) are implemented. Default to "dense".}

  \item{start}{An integer scalar with the genomic start
  coordinates for the highlighting range.}

  \item{...}{Additional items which will all be interpreted
  as further display parameters. See settings and the
  "Display Parameters" section below for details.}
}
\description{
  A function to plot genomic map of SNP using dataset from
  R package "TxDb.Hsapiens.UCSC.hg19.knownGene". The
  trancript track includes only major trancripts within a
  highlighting range.
}
\details{
  A function to plot genomic map of SNP using dataset of
  UCSC.hg19
}
\examples{
\dontrun{
library(TxDb.Hsapiens.UCSC.hg19.knownGene)
data(snp)
msb(M=snp,start=111950277,end=112036294)
}
}

